[pypy-commit] pypy stm-gc: Merge the usages of GCFLAG_MOVED and GCFLAG_VISITED.

arigo noreply at buildbot.pypy.org
Mon Apr 16 15:51:29 CEST 2012


Author: Armin Rigo <arigo at tunes.org>
Branch: stm-gc
Changeset: r54416:6a70fa336a29
Date: 2012-04-15 16:46 +0200
http://bitbucket.org/pypy/pypy/changeset/6a70fa336a29/

Log:	Merge the usages of GCFLAG_MOVED and GCFLAG_VISITED.

diff --git a/pypy/rpython/memory/gc/stmgc.py b/pypy/rpython/memory/gc/stmgc.py
--- a/pypy/rpython/memory/gc/stmgc.py
+++ b/pypy/rpython/memory/gc/stmgc.py
@@ -44,7 +44,6 @@
 GCFLAG_FIXED_HASH = first_gcflag << 3
 GCFLAG_WEAKREF    = first_gcflag << 4
 GCFLAG_VISITED    = first_gcflag << 5
-GCFLAG_MOVED      = first_gcflag << 6
 
 
 def always_inline(fn):
diff --git a/pypy/rpython/memory/gc/stmtls.py b/pypy/rpython/memory/gc/stmtls.py
--- a/pypy/rpython/memory/gc/stmtls.py
+++ b/pypy/rpython/memory/gc/stmtls.py
@@ -8,7 +8,6 @@
 from pypy.rpython.memory.gc.stmgc import WORD, NULL
 from pypy.rpython.memory.gc.stmgc import always_inline, dont_inline
 from pypy.rpython.memory.gc.stmgc import GCFLAG_GLOBAL, GCFLAG_VISITED
-from pypy.rpython.memory.gc.stmgc import GCFLAG_MOVED
 
 
 class StmGCTLS(object):
@@ -290,7 +289,7 @@
             return
         #
         # If 'obj' was already forwarded, change it to its forwarding address.
-        if hdr.tid & GCFLAG_MOVED:
+        if hdr.tid & GCFLAG_VISITED:
             root.address[0] = hdr.version
             return
         #
@@ -308,9 +307,9 @@
                              newobj - size_gc_header,
                              totalsize)
         #
         # Set the YOUNG copy's GCFLAG_MOVED and set its version to
         # point to the OLD copy.
-        hdr.tid |= GCFLAG_MOVED
+        hdr.tid |= GCFLAG_VISITED
         hdr.version = newobj
         #
         # Change the original pointer to this object.
@@ -308,9 +307,9 @@
                              totalsize)
         #
-        # Set the YOUNG copy's GCFLAG_MOVED and set its version to
+        # Set the YOUNG copy's GCFLAG_VISITED and set its version to
         # point to the OLD copy.


More information about the pypy-commit mailing list